# S3
Le module S3 est une bibliothèque PHP qui facilite l'interaction avec le service de stockage compatible S3 qu'il soit chez Amazon ou ailleurs. Il fournit une interface simple pour effectuer diverses opérations sur les objets stockés dans un compartiment S3, notamment le chargement, l'affichage, le téléchargement, la suppression, la vérification de l'existence et le listage des fichiers.

## Installation
### Composer
Ajouter les modules communs dans composer.json
```json
{
    "repositories": [{
            "type": "composer",
            "url": "https://git.nwb.fr/api/packages/modules-communs-php/composer"
        }
    ]
}
```
Lancer la commande
```bash
composer require nwb/s3:0.*.*
```
## Configuration
Pour utiliser le module S3, vous devez configurer certaines variables d'environnement. Voici la liste des variables nécessaires :

- `AWS_ACCESS_KEY_ID` : votre clé d'accès AWS.
- `AWS_SECRET_ACCESS_KEY` : votre clé d'accès secrète AWS.
- `AWS_REGION` : la région AWS dans laquelle votre bucket S3 est hébergé.
- `AWS_ENDPOINT` : l'URL de l'API S3. Cette variable est facultative et n'est nécessaire que si vous utilisez un fournisseur S3 autre qu'AWS.
- `AWS_S3_BUCKET` : le nom du bucket S3 que vous souhaitez utiliser.

Vous pouvez définir ces variables dans votre fichier `.env` ou dans les paramètres de votre serveur.

```bash
export AWS_ACCESS_KEY_ID=your_access_key
export AWS_SECRET_ACCESS_KEY=your_secret_key
export AWS_REGION=your_region
export AWS_ENDPOINT=your_endpoint
export AWS_S3_BUCKET=your_bucket_name
```

### Configuration Additionnelle de la Classe `ConfigS3`
La plupart du temps il n'est pas nécessaire de configurer la classe `ConfigS3` car les paramètres sont récupérés depuis les variables d'environnement. Cependant, pour des tests unitaires ou des transferts, il est possible, de configurer la classe `ConfigS3` en utilisant la méthode `setConfig` comme ci-dessous :
```php
$config = new ConfigS3();
$config->setConfig([
    'accessKey' => 'votre_access_key',
    'secretKey' => 'votre_secret_key',
    'region'    => 'votre_region',
    'bucket'    => 'votre_bucket',
    'endpoint'  => 'votre_endpoint'
]);
```

# Utilisation
```php
$s3 = new S3();
```

## Upload d'un Fichier
```php
$result = $s3->upload('chemin/du/fichier/local', 'chemin/du/seau/nom_du_fichier.jpg');
```
## Affichage d'un Fichier S3 dans le Navigateur
```php
$s3->show('chemin/du/seau/nom_du_fichier.jpg');
```
## Téléchargement d'un Fichier
```php
$s3->download('chemin/du/seau/nom_du_fichier.jpg', 'chemin/du/fichier/local');
```
## Suppression d'un Fichier sur S3
```php
$result = $s3->delete('chemin/du/seau/nom_du_fichier.jpg');
```
## listFiles
```php
$files = $s3->listFiles('chemin/du/seau/', true); // Le second paramètre à 'true' pour un listage récursif
foreach ($files as $file) {
    echo $file . PHP_EOL;
}
```
## Vérification de l'Existence d'un Fichier sur S3
```php
$existe = $s3->fileExists('dossier/seau/nom_du_fichier.jpg');
if ($existe) {
    echo "Le fichier existe sur S3.";
} else {
    echo "Le fichier n'existe pas sur S3.";
}
```

# Licence
Ce code est soumis au droit d'auteur et est la propriété intellectuelle de Nowwweb.com. Tous droits réservés. Aucune partie de ce logiciel ne peut être reproduite, distribuée, ou transmise sous quelque forme ou par quelque moyen que ce soit, y compris la photocopie, l'enregistrement, ou d'autres méthodes électroniques ou mécaniques, sans l'autorisation préalable écrite de l'éditeur.